@@ -19,6 +19,8 @@ from audeer.core.utils import (
     deprecated_keyword_argument,
     flatten_list,
     freeze_requirements,
+    git_repo_tags,
+    git_repo_version,
     is_uid,
     run_tasks,
     run_worker_threads,
