@@ -15,6 +15,9 @@ import warnings
 import audeer
 
 
+__doctest_skip__ = ['git_repo_tags', 'git_repo_version']
+
+
 def deprecated(
         *,
         removal_version: str,
@@ -179,6 +182,81 @@ def freeze_requirements(outfile: str):
             raise RuntimeError(f'Freezing Python packages failed: {err}')
 
 
+def git_repo_tags(
+        *,
+        v: bool = None,
+) -> typing.List:
+    r"""Get a list of available git tags.
+
+    The tags are inferred by executing
+    ``git tag`` in the current folder.
+    If the command fails,
+    an empty list is returned.
+
+    Args:
+        v: if ``True`` tags start always with ``v``,
+            if ``False`` they never start with ``v``,
+            if ``None`` the original tag names are returned
+
+    Returns:
+        list of tags
+
+    Example:
+        >>> git_repo_tags()
+        ['v1.0.0', 'v1.1.0', 'v2.0.0']
+
+    """
+    try:
+        git = ['git', 'tag']
+        tags = subprocess.check_output(git)
+        tags = tags.decode().strip().split('\n')
+    except Exception:  # pragma: nocover
+        tags = []
+    if v is None:
+        return tags
+    if v:
+        tags = [f'v{t}' if not t.startswith('v') else t for t in tags]
+    else:
+        tags = [t[1:] if t.startswith('v') else t for t in tags]
+    return tags
+
+
+def git_repo_version(
+        *,
+        v: bool = True,
+) -> str:
+    r"""Get a version number from current git ref.
+
+    The version is inferred executing
+    ``git describe --tags --always``.
+    If the command fails,
+    ``'<unknown>'`` is returned.
+
+    Args:
+        v: if ``True`` version starts always with ``v``,
+            otherwise it never starts with ``v``
+
+    Returns:
+        version number
+
+    Example:
+        >>> git_repo_version()
+        'v1.0.0'
+
+    """
+    try:
+        git = ['git', 'describe', '--tags', '--always']
+        version = subprocess.check_output(git)
+        version = version.decode().strip()
+    except Exception:  # pragma: nocover
+        version = '<unknown>'
+    if version.startswith('v') and not v:  # pragma: nocover (only local)
+        version = version[1:]
+    elif not version.startswith('v') and v:  # pragma: nocover (only github)
+        version = f'v{version}'
+    return version
+
+
 def is_uid(uid: str) -> bool:
     r"""Check if string is a unique identifier.
 
